@@ -1036,6 +1036,14 @@ struct ndpi_flow_struct {
             char hassh_client[33], hassh_server[33];
         } ssh;
 
+        struct {
+            u_int8_t username_detected:1, username_found:1,
+                     password_detected:1, password_found:1,
+                     _pad:4;
+            u_int8_t character_id;
+            char username[32], password[32];
+        } telnet;
+
         struct {
             char answer[96];
         } mdns;
