@@ -157,7 +157,12 @@ static void nd_usage(int rc = 0, bool version = false)
 #endif
     }
     else {
-        fprintf(stderr, "See netifyd(8) and netifyd.conf(5) for help.\n");
+        fprintf(stderr, "Basic options:\n"
+            "\t--status\tdisplay agent status\n"
+            "\t--provision\tprovision agent\n"
+            "\t--enable-sink\tenable/disable sink uploads\n"
+            "\t--disable-sink\n\n"
+            "See netifyd(8) and netifyd.conf(5) for further help.\n");
     }
 
     exit(rc);
@@ -278,6 +283,8 @@ static int nd_config_load(void)
         "netifyd", "upload_connect_timeout", ND_SINK_CONNECT_TIMEOUT);
     nd_config.sink_xfer_timeout = (unsigned)reader.GetInteger(
         "netifyd", "upload_timeout", ND_SINK_XFER_TIMEOUT);
+    ND_GF_SET_FLAG(ndGF_UPLOAD_NAT_FLOWS, reader.GetBoolean(
+        "netifyd", "upload_nat_flows", false));
 
     ND_GF_SET_FLAG(ndGF_JSON_SAVE,
         reader.GetBoolean("netifyd", "json_save", false));
@@ -1156,8 +1163,8 @@ static void nd_json_add_flows(json &parent,
     for (nd_flow_map::const_iterator i = flows->begin();
         i != flows->end(); i++) {
 
-        if (i->second->detection_complete == false || ! i->second->ts_first_update)
-            continue;
+        if (i->second->detection_complete == false || ! i->second->ts_first_update
+            || (! ND_UPLOAD_NAT_FLOWS && i->second->ip_nat)) continue;
 
         json jf;
         i->second->json_encode(jf, ndpi);
@@ -1608,15 +1615,13 @@ static void nd_dump_stats(void)
             if (ND_UPLOAD_ENABLED)
                 thread_sink->QueuePush(json_string);
             else {
-                if (ND_USE_SINK || ND_JSON_SAVE) {
-                    j["version"] = (double)ND_JSON_VERSION;
-                    j["timestamp"] = time(NULL);
-                    j["uptime"] = nda_stats.ts_now.tv_sec - nda_stats.ts_epoch.tv_sec;
-                    j["ping"] = true;
+                j["version"] = (double)ND_JSON_VERSION;
+                j["timestamp"] = time(NULL);
+                j["uptime"] = nda_stats.ts_now.tv_sec - nda_stats.ts_epoch.tv_sec;
+                j["ping"] = true;
 
-                    nd_json_to_string(j, json_string);
-                    thread_sink->QueuePush(json_string);
-                }
+                nd_json_to_string(j, json_string);
+                thread_sink->QueuePush(json_string);
             }
         }
         catch (runtime_error &e) {
